summaryrefslogtreecommitdiffstats
path: root/include/camera
diff options
context:
space:
mode:
Diffstat (limited to 'include/camera')
-rw-r--r--include/camera/Camera.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/camera/Camera.h b/include/camera/Camera.h
index b1b2e95..79682b8 100644
--- a/include/camera/Camera.h
+++ b/include/camera/Camera.h
@@ -81,9 +81,9 @@ public:
status_t unlock();
// pass the buffered IGraphicBufferProducer to the camera service
- status_t setPreviewTexture(const sp<IGraphicBufferProducer>& bufferProducer);
+ status_t setPreviewTarget(const sp<IGraphicBufferProducer>& bufferProducer);
- // start preview mode, must call setPreviewTexture first
+ // start preview mode, must call setPreviewTarget first
status_t startPreview();
// stop preview mode
@@ -92,7 +92,7 @@ public:
// get preview state
bool previewEnabled();
// start recording mode, must call setPreviewTexture first
status_t startRecording();
// stop recording mode
@@ -92,7 +92,7 @@ public:
// get preview state
bool previewEnabled();
- // start recording mode, must call setPreviewTexture first
+ // start recording mode, must call setPreviewTarget first
status_t startRecording();
// stop recording mode